@@ -1,14 +1,15 @@
 package WWW::FetchStory::Fetcher::LiveJournal;
-$WWW::FetchStory::Fetcher::LiveJournal::VERSION = '0.1828';
+$WWW::FetchStory::Fetcher::LiveJournal::VERSION = '0.19';
 use strict;
 use warnings;
+use HTML::Entities;
 =head1 NAME
 
 WWW::FetchStory::Fetcher::LiveJournal - fetching module for WWW::FetchStory
 
 =head1 VERSION
 
-version 0.1828
+version 0.19
 
 =head1 DESCRIPTION
 
@@ -378,6 +379,7 @@ sub parse_title {
     {
 	$title = $1;
     }
+    $title = decode_entities($title); # get rid of HTML entities in the title
     $title =~ s/<u>//ig;
     $title =~ s/<\/u>//ig;
     return $title;
